# VS Code Auxiliary Files

This folder contains some helper files that speed up development within Visual Studio Code:

- ```launch.json``` describes the behaviour when debugging Python files within the repo.
- ```snippets/``` contains code snippets for creating OpenFisca constructs.

## Code Snippets

The ```snippets/``` folder contains two files:

- ```python.json``` contains snippets for creating variables, formulas and initialising new variables files.
- ```yaml.json``` contains snippets for creating tests and parameters.

There is a variety of extensions that automatically read in the code snippets, such as [Project Snippets](https://marketplace.visualstudio.com/items?itemName=rebornix.project-snippets), or the same can be achieved by pasting the contents of the files into the user snippets files (accessible via <kbd>CTRL</kbd>+<kbd>SHIFT</kbd>+<kbd>P</kbd> and selecting ```Preferences: configure user snippets```).
